@@ -1,4 +1,5 @@
 import os
+from datetime import datetime as dt
 
 from flask import Flask, jsonify, request
 from flask_cors import CORS
@@ -7,13 +8,14 @@ from sqlalchemy import create_engine
 app = Flask(__name__)
 CORS(app)
 
-@app.route('/ping', methods=['GET'])
+@app.route('/api/v1/ping', methods=['GET'])
 def ping():
     return jsonify({'message': 'I an here'}), 200
 
 
-@app.route('/execute', methods=['GET'])
+@app.route('/api/v1/execute', methods=['GET'])
 def execute():
+    t1 = dt.now()
     # get passed data
     data = request.json if request.json else {}
     data.update(request.args)
@@ -33,16 +35,30 @@ def execute():
     # run 
     engine = create_engine(app.config['DB_URI'])
     with engine.connect() as con:
-        res = con.execute(sql)
+        t2 = dt.now()
+        try:
+            res = con.execute(sql)
+        except Exception as e:
+            return jsonify({
+                'message': 'Run errored!',
+                'params': data,
+                'error': True,
+                'data': [dict(errorMessage=str(e))]
+            })
+        t3 = dt.now()
 
     return jsonify({
         'message': 'Run successful',
-        'data': data,
-        'result': [dict(r) for r in res]
+        'params': data,
+        'data': [dict(r) for r in res],
+        'perf': dict(
+            backendTime=(t3 - t2).total_seconds(), 
+            executionTime=(t3 - t1).total_seconds()
+        )
     })
 
 
-def run(db_uri, debug=False, port=5000):
+def run(db_uri, debug=False, port=5000, host='localhost'):
     """
     Hydenv Exercise backend server\n
     For local execution of exercises. Usually, the exercise 
@@ -51,7 +67,7 @@ def run(db_uri, debug=False, port=5000):
     you need to start it before you start the exercises.
     """
     app.config['DB_URI'] = db_uri
-    app.run(debug=debug, port=port)
+    app.run(debug=debug, port=port, host=host)
 
 
 if __name__=='__main__':
